@@ -20,7 +20,7 @@ from matplotlib.ticker import NullFormatter
 
 def title(i: Input,
           axe=None,
-          scenario="",
+          scenario=None,
           diff_L_R=None,
           extra="",
           cms_energy=True,
@@ -32,8 +32,9 @@ def title(i: Input,
         axe = plt.gca()
     axe.set_title("$pp\\to" + get_name(i.particle1) + get_name(i.particle2) +
                   "$" + (" at $\\sqrt{S} = " + str(i.energy / 1000) +
-                         "$ TeV" if cms_energy else "") + " for " +
-                  (i.slha.split(".")[0] if scenario == "" else scenario) +
+                         "$ TeV" if cms_energy else "") +
+                  ((" for " +
+                    i.slha.split(".")[0]) if scenario is None else scenario) +
                   (" with " + i.pdf_nlo if pdf_info else "") + " " + extra +
                   ((" [" + i.id + "]") if id else ""))
 
@@ -64,14 +65,17 @@ def mass_plot(dict_list,
               yaxis="$\\sigma$ [pb]",
               yscale=1.,
               label=None,
+              xaxis = None,
               **kwargs):
     dict_list["mass_" + str(part)] = get_mass(dict_list, abs(part))
+    if xaxis is None:
+        xaxis = "$m_{" + get_name(part) + "}$ [GeV]"
     plot(dict_list,
          "mass_" + str(part),
          y,
          label=label,
-         xaxis="$m_{" + get_name(part) + "}$ [GeV]",
          yaxis=yaxis,
+         xaxis=xaxis,
          logy=logy,
          yscale=yscale,
          **kwargs)
@@ -225,25 +229,25 @@ def vplot(x,
         vx = x
         vy = y
 
-    
-    if data_color is None:
+    if data_color is None and 'next_color' not in kwargs:
         if 'axes' in kwargs and kwargs['axes'] is not None:
             bl, = kwargs['axes'].plot([], [])
         else:
             bl, = plt.gca().plot([], [])
         color = bl.get_color()
     iii = splot.data(vx,
-                            vy * yscale,
-                            label=label,
-                            xaxis=xaxis,
-                            yaxis=yaxis,
-                            logy=logy,
-                            data_color=color,
-                            also_data=plot_data,
-                            interpolate=interpolate,
-                            fmt=data_fmt,
-                            sigmas=0 if not fill else 1,
-                            **kwargs)
+                     vy * yscale,
+                     label=label,
+                     xaxis=xaxis,
+                     yaxis=yaxis,
+                     logy=logy,
+                     data_color=color,
+                     fit_color=color,
+                     also_data=plot_data,
+                     interpolate=interpolate,
+                     fmt=data_fmt,
+                     sigmas=0 if not fill else 1,
+                     **kwargs)
     if iii is not None:
         #ii = iii[0]
         ix = iii[1]
@@ -259,6 +263,7 @@ def vplot(x,
                    yaxis=yaxis,
                    logy=logy,
                    data_color=color,
+                   fit_color=color,
                    also_data=plot_data,
                    interpolate=interpolate,
                    interpolate_fmt=(0, (3, 1, 3, 1, 1, 1)),
@@ -320,8 +325,10 @@ def mapplot(dict_list, x, y, z, xaxis=None, yaxis=None, zaxis=None, **kwargs):
                  zaxis=zaxis,
                  **kwargs)
 
-map_vplot =  lambda *a,**da : splot.plot2d(*a,style="image",**da)
-scatter_vplot =  lambda *a,**da : splot.plot2d(*a,style="scatter",**da)
+
+map_vplot = lambda *a, **da: splot.plot2d(*a, style="image", **da)
+scatter_vplot = lambda *a, **da: splot.plot2d(*a, style="scatter", **da)
+
 
 def scatterplot(dict_list,
                 x,
